/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.0
import MinuteMonitor 0.1

// Display color coded (by call type) log entries 
Rectangle
{
	id: labelList
	anchors.fill: parent
	color: "#353535"
	// reminder, store is not available when constructed, don't bind
	// properties until onCompleted
	Component.onCompleted : 
	{
		// The Connections didn't seem to work, but this callback
		// does and gets called from the correct object.
		windowStack.hidden.connect(function()
		{
			labelList.destroy()
		})
	}

	ListView
	{
		id: listView
		model: labelModel
		anchors.fill: parent
		pressDelay: press_delay
		focus: true
		keyNavigationWraps: true // quick wrap around
		highlight: Rectangle { color: selected_color }
		highlightMoveDuration: 1
		delegate:
		Item
		{
			id: button
			width: parent.width
			height: Math.max(name.height+uid.height,
				start_time.height+minutes.height) + 6
			// Give each row a black background.
			Rectangle
			{
				// set to draw before the highlight component
				parent: button.parent
				z: -100
				y: button.y
				height: button.height
				width: button.width
				color: "black"
			}
			Text
			{
				id: name
				y: 3
				x: 5
				text: model.remote_name
				color: "white"
			}
			Text
			{
				id: uid
				y: 3 + name.height
				x: 15
				text: model.remote_uid
				color: "white"
				font.pointSize: name.font.pointSize*.8
			}
			Rectangle
			{
				color:
					model.type == CallType.CALL_COST ?
						"red" :
					model.type == CallType.CALL_FREE ?
						"yellow" :
					model.type == CallType.CALL_VOIP ?
						"green" : "black"
				anchors.fill: call_type
				visible: model.type <= CallType.CALL_VOIP
			}
			Text
			{
				id: call_type
				x: parent.width - width - 25
				y: 3
				text: model.type == CallType.CALL_COST ?
						" Cost " :
					model.type == CallType.CALL_FREE ?
						" Free " :
					model.type == CallType.CALL_VOIP ?
						" VoIP " : " unknown "
				color: "black"
			}
			Text
			{
				id: minutes
				x: call_type.x - width - 25
				y: 3
				text: model.minutes
				color: "white"
			}
			Rectangle
			{
				color: 
					(model.rate & CallType.DAYTIME_RATE ?
						"Red" :
					model.rate & CallType.EVENING_RATE ?
						"Yellow" : "black")
				anchors.fill: call_rate
				visible: call_rate.visible
			}
			Text
			{
				id: call_rate
				anchors.top: start_time.top
				anchors.right: start_time.left
				anchors.rightMargin: 5
				text: (model.rate & CallType.DAYTIME_RATE ?
						" Day " : "") +
					(model.rate & CallType.EVENING_RATE ?
						" Evening " : "")
				font.pointSize: name.font.pointSize*.8
				visible: text != ""
			}
			Text
			{
				id: start_time
				x: parent.width - width - 40
				y: 3 + minutes.height
				text: model.start_time
				font.pointSize: name.font.pointSize*.8
				color: "white"
			}
			Rectangle
			{
				height: 1
				x : 20
				width: parent.width - 2*x
				color: divider_color
			}
			MouseArea
			{
				anchors.fill: button
				onPressed: listView.currentIndex=index
				/*
				onReleased: listView.currentIndex=-1
				onCanceled: listView.currentIndex=-1
				*/
				function edit()
				{
					create("EditType.qml", function(obj)
					{
						obj.parent=labelList
						obj.model=model
						obj.update()
					})
				}
				onClicked: edit()
				focus: listView.currentIndex==index
				Keys.onEnterPressed: edit()
			}
		}
	}
	ScrollDecorator
	{
		flickableItem: listView
	}
}
